@@ -1,36 +1,42 @@
 package Path::Dispatcher::Path;
-use Any::Moose;
+# ABSTRACT: path and some optional metadata
 
+our $VERSION = '1.07';
+
+use Moo;
+
+use Types::Standard qw(Str HashRef);
 use overload q{""} => sub { shift->path };
 
 has path => (
     is        => 'ro',
-    isa       => 'Str',
+    isa       => Str,
     predicate => 'has_path',
 );
 
 has metadata => (
     is        => 'ro',
-    isa       => 'HashRef',
+    isa       => HashRef,
     predicate => 'has_metadata',
 );
 
 # allow Path::Dispatcher::Path->new($path)
-sub BUILDARGS {
+around BUILDARGS => sub {
+    my $orig = shift;
     my $self = shift;
 
     if (@_ == 1 && !ref($_[0])) {
         unshift @_, 'path';
     }
 
-    $self->SUPER::BUILDARGS(@_);
+    $self->$orig(@_);
 };
 
 sub clone_path {
     my $self = shift;
     my $path = shift;
 
-    return $self->meta->clone_object($self, path => $path, @_);
+    return $self->new({ %$self, path => $path, @_ });
 }
 
 sub get_metadata {
@@ -41,16 +47,24 @@ sub get_metadata {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Any::Moose;
+no Moo;
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Path::Dispatcher::Path - path and some optional metadata
 
+=head1 VERSION
+
+version 1.07
+
 =head1 SYNOPSIS
 
     my $path = Path::Dispatcher::Path->new(
@@ -75,5 +89,20 @@ string. :)
 A hash representing arbitrary metadata. The L<Path::Dispatcher::Rule::Metadata>
 rule is designed to match against members of this hash.
 
-=cut
+=head1 SUPPORT
 
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Path-Dispatcher>
+(or L<bug-Path-Dispatcher@rt.cpan.org|mailto:bug-Path-Dispatcher@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, C<< <sartak at bestpractical.com> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
