@@ -1,10 +1,16 @@
 package Path::Dispatcher::Rule::CodeRef;
-use Any::Moose;
+# ABSTRACT: predicate is any subroutine
+
+our $VERSION = '1.07';
+
+use Moo;
+
+use Types::Standard qw(CodeRef);
 extends 'Path::Dispatcher::Rule';
 
 has matcher => (
     is       => 'ro',
-    isa      => 'CodeRef',
+    isa      => CodeRef,
     required => 1,
 );
 
@@ -17,16 +23,24 @@ sub _match {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Any::Moose;
+no Moo;
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Path::Dispatcher::Rule::CodeRef - predicate is any subroutine
 
+=head1 VERSION
+
+version 1.07
+
 =head1 SYNOPSIS
 
     my $rule = Path::Dispatcher::Rule::CodeRef->new(
@@ -59,5 +73,20 @@ strings (the results).
 The coderef receives the path object as its argument, and the path string as
 C<$_>.
 
-=cut
+=head1 SUPPORT
 
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Path-Dispatcher>
+(or L<bug-Path-Dispatcher@rt.cpan.org|mailto:bug-Path-Dispatcher@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, C<< <sartak at bestpractical.com> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
