@@ -1,16 +1,22 @@
 package Path::Dispatcher::Rule::Enum;
-use Any::Moose;
+# ABSTRACT: one of a list of strings must match
+
+our $VERSION = '1.07';
+
+use Moo;
+use Types::Standard qw(Str ArrayRef Bool);
+
 extends 'Path::Dispatcher::Rule';
 
 has enum => (
     is       => 'ro',
-    isa      => 'ArrayRef[Str]',
+    isa      => ArrayRef[Str],
     required => 1,
 );
 
 has case_sensitive => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 1,
 );
 
@@ -86,16 +92,24 @@ sub complete {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Any::Moose;
+no Moo;
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Path::Dispatcher::Rule::Enum - one of a list of strings must match
 
+=head1 VERSION
+
+version 1.07
+
 =head1 SYNOPSIS
 
     my $rule = Path::Dispatcher::Rule::Enum->new(
@@ -114,6 +128,20 @@ L</enum> strings.
 
 =head2 case_sensitive
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Path-Dispatcher>
+(or L<bug-Path-Dispatcher@rt.cpan.org|mailto:bug-Path-Dispatcher@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, C<< <sartak at bestpractical.com> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
