@@ -1,16 +1,22 @@
 package Path::Dispatcher::Rule::Eq;
-use Any::Moose;
+# ABSTRACT: predicate is a string equality
+
+our $VERSION = '1.07';
+
+use Moo;
+use Types::Standard qw(Str Bool);
+
 extends 'Path::Dispatcher::Rule';
 
 has string => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has case_sensitive => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 1,
 );
 
@@ -67,16 +73,24 @@ sub complete {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Any::Moose;
+no Moo;
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Path::Dispatcher::Rule::Eq - predicate is a string equality
 
+=head1 VERSION
+
+version 1.07
+
 =head1 SYNOPSIS
 
     my $rule = Path::Dispatcher::Rule::Eq->new(
@@ -92,5 +106,20 @@ Rules of this class simply check whether the string is equal to the path.
 
 =head2 string
 
-=cut
+=head1 SUPPORT
 
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Path-Dispatcher>
+(or L<bug-Path-Dispatcher@rt.cpan.org|mailto:bug-Path-Dispatcher@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, C<< <sartak at bestpractical.com> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
