@@ -1,23 +1,28 @@
 package Path::Dispatcher::Rule::Tokens;
-use Any::Moose;
+# ABSTRACT: predicate is a list of tokens
+
+our $VERSION = '1.07';
+
+use Moo;
+use Types::Standard qw(Str ArrayRef Bool);
+
 extends 'Path::Dispatcher::Rule';
 
 has tokens => (
     is         => 'ro',
-    isa        => 'ArrayRef',
-    auto_deref => 1,
+    isa        => ArrayRef,
     required   => 1,
 );
 
 has delimiter => (
     is      => 'ro',
-    isa     => 'Str',
+    isa     => Str,
     default => ' ',
 );
 
 has case_sensitive => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 1,
 );
 
@@ -26,7 +31,7 @@ sub _match_as_far_as_possible {
     my $path = shift;
 
     my @got      = $self->tokenize($path->path);
-    my @expected = $self->tokens;
+    my @expected = @{ $self->tokens };
     my @matched;
 
     while (@got && @expected) {
@@ -139,16 +144,24 @@ sub untokenize {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Any::Moose;
+no Moo;
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Path::Dispatcher::Rule::Tokens - predicate is a list of tokens
 
+=head1 VERSION
+
+version 1.07
+
 =head1 SYNOPSIS
 
     my $rule = Path::Dispatcher::Rule::Tokens->new(
@@ -196,5 +209,20 @@ this to a slash.
 Decide whether the rule matching is case sensitive. Default is 1, case
 sensitive matching.
 
-=cut
+=head1 SUPPORT
 
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Path-Dispatcher>
+(or L<bug-Path-Dispatcher@rt.cpan.org|mailto:bug-Path-Dispatcher@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, C<< <sartak at bestpractical.com> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
