@@ -1,18 +1,25 @@
 package Path::Dispatcher::Rule::Under;
-use Any::Moose;
-use Any::Moose '::Util::TypeConstraints';
+# ABSTRACT: rules under a predicate
+
+our $VERSION = '1.07';
+
+use Moo;
+use Type::Tiny;
+use Type::Utils qw(class_type);
 
 extends 'Path::Dispatcher::Rule';
 with 'Path::Dispatcher::Role::Rules';
 
-subtype 'Path::Dispatcher::PrefixRule'
-     => as 'Path::Dispatcher::Rule'
-     => where { $_->prefix }
-     => message { "This rule ($_) does not match just prefixes!" };
+my $PREFIX_RULE_TYPE = "Type::Tiny"->new(
+    name       => "PrefixRule",
+    parent     => class_type("Path::Dispatcher::Rule"),
+    constraint => sub { return ( shift()->prefix ) ? 1 : 0 },
+    message    => sub { "This rule ($_) does not match just prefixes!" },
+);
 
 has predicate => (
     is  => 'ro',
-    isa => 'Path::Dispatcher::PrefixRule',
+    isa => $PREFIX_RULE_TYPE
 );
 
 sub match {
@@ -71,16 +78,24 @@ sub complete {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Any::Moose;
+no Moo;
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Path::Dispatcher::Rule::Under - rules under a predicate
 
+=head1 VERSION
+
+version 1.07
+
 =head1 SYNOPSIS
 
     my $ticket = Path::Dispatcher::Rule::Tokens->new(
@@ -125,5 +140,20 @@ as the path for the contained rules.
 A list of rules that will be try to be matched only if the predicate is
 matched.
 
-=cut
+=head1 SUPPORT
 
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Path-Dispatcher>
+(or L<bug-Path-Dispatcher@rt.cpan.org|mailto:bug-Path-Dispatcher@rt.cpan.org>).
+
+=head1 AUTHOR
+
+Shawn M Moore, C<< <sartak at bestpractical.com> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Shawn M Moore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
